#%%
"""
Graph RGB image from HSI cube from 31 Aug with circular masks and plant ID labels 
"""

import hsi_functions as hsi
import hsi_shoot_locs as slocs
import spectral as spy
import numpy as np
import matplotlib.pyplot as plt
import matplotlib.patheffects as pe
from matplotlib.patches import Circle
from data_directory_path import data_directory
import os
os.chdir(data_directory)

# Save plot? 
save = True

#%%
dir0 = './data/HSI/HSI_output/refl_HSI_data/'
imdir = dir0 + '/20220831_refl-allIT__rep2'

im = hsi.read_img(imdir)
wav, fwhm = hsi.get_wav(imdir)

def plot_rgb(img, wav, save = False, output_fn = './graphs/Figure_1d'):
    """
    Function that plots an RGB image from HSI cube with circle masks plotted in
    """
    font = {'size': 14}  
    plt.rc('font', **font)

    iRed = hsi.find_nearest_idx(wav, 630)
    iGreen = hsi.find_nearest_idx(wav, 530)
    iBlue = 3

    rgb_img = np.transpose(img, (1,2,0))

    fig = plt.figure(figsize=(7,7))
    ax = fig.add_subplot(111)
    
    spy.imshow(rgb_img, (iRed, iGreen, iBlue), stretch = 0.01, fignum = 1)

    plt.text(x=90, y= 250, s='54 D', color='white', size=24, weight='bold') 
    plt.text(x=790, y= 240, s='10 D', color='white',  size=24, weight='bold')
    plt.text(x=120, y= 890, s='55 D', color='white',  size=24, weight='bold')
    plt.text(x=810, y= 880, s='9 D', color='white',  size=24, weight='bold')
    plt.text(x=400, y= 140, s='25 C', color='white',  size=24, weight='bold')
    plt.text(x=850, y= 550, s='28 C', color='white',  size=24, weight='bold')
    plt.text(x=500, y=900, s='6 C', color='white',  size=24, weight='bold')
    plt.text(x=240, y= 570, s='30 C', color='white',  size=24, weight='bold')

    for loc in slocs.sloc_dict['20220831']:
        circ = Circle(loc,50, edgecolor='white', facecolor='none', linewidth=3)
        ax.add_patch(circ)
    plt.axis('off')
    plt.tight_layout()

    if save == True:
        plt.savefig(output_fn + '.png', pad_inches=0,format='png',dpi=600,bbox_inches='tight')
        plt.savefig(output_fn + '.pdf', pad_inches=0,format='pdf',dpi=600,bbox_inches='tight')

    plt.show()


plot_rgb(im, wav, save=save, output_fn = './graphs/Figure_1d')