#%%
"""
Plot timeseries of SM, LWP, YPSIImax (Fig. 2)
"""
import matplotlib.pyplot as plt
import matplotlib.dates as mdates
import seaborn as sns
import pandas as pd
from matplotlib import ticker
from fig_colors import treatment_palette as c_palette 
from data_directory_path import data_directory
import os
os.chdir(data_directory)

# Save plot? 
save = True

#%%
data = pd.read_csv('./data/data_all.csv', sep=',')
data['Date'] = pd.to_datetime(data['Date'], format='%Y%m%d')

# LWP in is Bar, convert to MPa
data['LWP_MPa'] = data['LWP']/10 

cols = ['SM','LWP_MPa', 'Y_II_MAX']
titles = ['(a)', '(b)', '(c)']
y_labs = [  'SM (%)',
          'Ψ$\mathregular{_{W}}$ (MPa)',
          'Φ$\mathit{PSII_{MAX}}$']

# Font sizes
SMALL_SIZE = 12
MEDIUM_SIZE = 14
BIGGER_SIZE = 16
plt.rc('font', size=MEDIUM_SIZE) 
plt.rc('axes', titlesize=MEDIUM_SIZE)  
plt.rc('axes', labelsize=MEDIUM_SIZE) 
plt.rc('xtick', labelsize=SMALL_SIZE)   
plt.rc('ytick', labelsize=SMALL_SIZE)    
plt.rc('legend', fontsize=SMALL_SIZE)    

fig, axs = plt.subplots(nrows=2, ncols=2, figsize=(9, 6))
plt.subplots_adjust(hspace=0.4, wspace= 0.2)

counter = -1
for y_lab, title, col, ax in zip(y_labs, titles, cols, axs.ravel()) :
    sns.lineplot(data=data, ax=ax, 
             x='Date', y=col, palette=c_palette, 
             hue='Treatment', hue_order=['C', 'D'],
             errorbar=('ci', 95))
    
    ax.text(0.01, .97, title, ha='left', va='top', transform=ax.transAxes,  
            fontdict ={'size':14, 'weight': 'bold'})
    ax.set_xlabel('')
    ax.set_ylabel(y_lab)

    ax.yaxis.set_major_locator(ticker.MaxNLocator(4))
    ax.set_xticks(ticks=[pd.to_datetime('2022-08-15'),
                         pd.to_datetime('2022-08-31')])
    ax.xaxis.set_major_formatter(mdates.DateFormatter('%b %d'))
    

    y_min, y_max = ax.get_ylim() 
    diff = y_max - y_min
    ax.scatter(pd.to_datetime('2022-08-14 22:00'), 
               y_min+(diff*0.08), c=c_palette[1],  linewidth=0.2,
               marker=r'$\downarrow$',s=300, label='Irrigation\nresumed', zorder=2)
    ax.scatter(pd.to_datetime('2022-08-30 22:00'), 
               y_min+(diff*0.08), c=c_palette[0], linewidth=0.2,
               marker=r'$\downarrow$',s=300, label='Irrigation\nresumed', zorder=2)
    
    lgdn = ax.legend()
    lgdn.remove()
    
        
    ax.tick_params(axis='x', labelrotation=0)

axs[1,1].axis('off')

handles, labels = axs[0,0].get_legend_handles_labels()
lgdn = axs[1,1].legend(handles=handles, 
                         labels=['Control', 'Water stress','Irrigation\nstop', 'Irrigation\nresumed'], 
                        title='', loc='center', ncol=2, borderpad=1, labelspacing=1.5)
lgdn.get_frame().set_boxstyle('Square')

plt.tight_layout()

if save == True:
    output_fn = './graphs/Figure_2'
    plt.savefig(output_fn + '.png', format='png', bbox_inches='tight', dpi=600)
    plt.savefig(output_fn + '.pdf', format='pdf', bbox_inches='tight', dpi=600)

plt.show()


