#%%
"""
Plot  ΔPRI=PRI_C-PRI_D timeseries (Fig. 3 b)
"""

import pandas as pd
import matplotlib.pyplot as plt
import seaborn as sns
import matplotlib.dates as mdates
from matplotlib.lines import Line2D
import numpy as np
from fig_colors import treatment_palette as c_palette 
from data_directory_path import data_directory
import os
os.chdir(data_directory)

# Save plot? 
save = True

# plot arrows?
plot_arrows = False

#%%
data = pd.read_csv('./data/data_all__nosat.csv', sep=',')
data['Date'] = pd.to_datetime(data['Date'], format='%Y%m%d')

# set font sizes
SMALL_SIZE = 12
MEDIUM_SIZE = 14
BIGGER_SIZE = 16
plt.rc('font', size=MEDIUM_SIZE) 
plt.rc('axes', titlesize=MEDIUM_SIZE)  
plt.rc('axes', labelsize=MEDIUM_SIZE) 
plt.rc('xtick', labelsize=SMALL_SIZE)   
plt.rc('ytick', labelsize=SMALL_SIZE)    
plt.rc('legend', fontsize=SMALL_SIZE)    

D_PRI = {}
dates = data['Date'].unique()
for date in dates:
    control_pri = np.nanmean(data[(data['Date'] == date) & (data['Treatment'] == 'C')]['PRI_circle'])
    drought_pri = np.nanmean(data[(data['Date'] == date) & (data['Treatment'] == 'D')]['PRI_circle'])
    D_PRI[date] = control_pri - drought_pri
D_PRI = pd.DataFrame(list(D_PRI.items()),
                      columns=['Date','PRI'])

fig, ax = plt.subplots(nrows=1, ncols=1, figsize=(5, 3))
plt.subplots_adjust(hspace=0.4, wspace= 0.2)

sns.lineplot(data=D_PRI, x='Date', y='PRI', color=c_palette[0], linewidth=3.6)
sns.lineplot(data=D_PRI[3:14], x='Date', y='PRI', color=c_palette[1], linewidth=4)

ax.text(0.02, .89, '(b)', transform=ax.transAxes, fontdict ={'size':14, 'weight': 'bold'})
ax.set_xlabel('')
ax.set_ylabel('ΔPRI =\nPRI$\mathregular{_{C}}$ - PRI$\mathregular{_{D}}$')
handles, labels = ax.get_legend_handles_labels()

handles = [Line2D([0], [0], label='Irrigation ON', color=c_palette[0], linewidth=3.5),
           Line2D([0], [0], label='Irrigation OFF', color=c_palette[1], linewidth=3.5)]
ax.legend(handles=handles, loc='lower right')

ax.set_yticks([0, 0.01, 0.02])
ax.set_xticks(ticks=[pd.to_datetime('2022-08-15'),
                        pd.to_datetime('2022-08-31')])
ax.xaxis.set_major_formatter(mdates.DateFormatter('%b %d'))

if plot_arrows == True:
    ax.scatter(pd.to_datetime('2022-08-14 22:00'), 
                0.01, c=c_palette[1], edgecolor=c_palette[1], linewidth=0.2,
                marker=r'$\downarrow$',s=400, label='Irrigation\nstop', zorder=2)
    ax.scatter(pd.to_datetime('2022-08-30 22:00'), 
                0.01, c=c_palette[0], edgecolor=c_palette[0], linewidth=0.2,
                marker=r'$\downarrow$',s=400, label='Irrigation\nresumed', zorder=2)


if save == True:
    output_fn = './graphs/Figure_3b__nosat'
    plt.savefig(output_fn + '.png', bbox_inches='tight', dpi=600)

plt.show()
# %%
