#%%
"""
Plot timeseries of meteorological data, (a) temp and (b) PAR (Appendix Fig. A1)
"""

import matplotlib.pyplot as plt
from matplotlib import ticker
import matplotlib.dates as mdates
import pandas as pd
import numpy as np
from fig_colors import treatment_palette as c_palette 
from data_directory_path import data_directory
import os
os.chdir(data_directory)

# Save plot?
save = True

#%%
met_data = pd.read_csv('./data/temp-and-PAR.csv')
met_data['Date'] = pd.to_datetime(met_data['Date'], format='%Y%m%d')

# Set font sizes
SMALL_SIZE = 12
MEDIUM_SIZE = 14
BIGGER_SIZE = 16
plt.rc('font', size=MEDIUM_SIZE) 
plt.rc('axes', titlesize=MEDIUM_SIZE)  
plt.rc('axes', labelsize=MEDIUM_SIZE) 
plt.rc('xtick', labelsize=SMALL_SIZE)   
plt.rc('ytick', labelsize=SMALL_SIZE)    
plt.rc('legend', fontsize=SMALL_SIZE)    

fig, axs  = plt.subplots(ncols=2, nrows=1, figsize=(9, 3))

date = met_data['Date']
temp =met_data['room_temp_midday']
PAR_GH = met_data['PAR_indoor'].replace(-999, np.NaN)

edge_c  = None

axs[0].plot(date, temp, marker='o', color='black', markeredgecolor=edge_c, markersize=5, linewidth=0)
axs[0].set_ylabel('Temp. (°C)')
axs[0].text(0.025, 0.88,'(a)', transform=axs[0].transAxes,  
            fontdict ={'size':14, 'weight': 'bold'})
axs[0].set_ylim(5, 38)

axs[1].plot(date, PAR_GH, color='black', markeredgecolor=edge_c, marker='o', markersize=5, linewidth=0)
axs[1].set_ylabel('PAR (µmol m$\mathregular{^{-2}}$ $\mathregular{s^{-1}}$)')
axs[1].text(0.025, 0.88,'(b)', transform=axs[1].transAxes,  
            fontdict ={'size':14, 'weight': 'bold'})
axs[1].set_ylim(50, 400)


for ax in axs.ravel():
    y_min, y_max = ax.get_ylim() 
    diff = y_max - y_min
    ax.scatter(pd.to_datetime('2022-08-14 23:00'), 
               y_min+(diff*0.08), c=c_palette[1],  linewidth=0.2,
               marker=r'$\downarrow$',s=300, label='Irrigation\nresumed', zorder=2)
    ax.scatter(pd.to_datetime('2022-08-30 23:00'), 
               y_min+(diff*0.08), c=c_palette[0], linewidth=0.2,
               marker=r'$\downarrow$',s=300, label='Irrigation\nresumed', zorder=2)
    ax.set_xticks(ticks=[pd.to_datetime('2022-08-15'),
                         pd.to_datetime('2022-08-31')])
    ax.xaxis.set_major_formatter(mdates.DateFormatter('%b %d'))
    


plt.tight_layout()

if save == True:
    output_fn = './graphs/Figure_A1'
    plt.savefig(output_fn + '.png',  bbox_inches='tight', dpi=600)
    plt.savefig(output_fn + '.pdf',  bbox_inches='tight', dpi=600)

plt.show()