#%%
"""
Plot timseries of (a) PRI and (b) REP by plant (Appendix Fig. A5)
"""
import matplotlib.pyplot as plt
from matplotlib.patches import Patch
import matplotlib.dates as mdates
import seaborn as sns
import pandas as pd
from matplotlib import ticker
from fig_colors import plant_palette as c_palette 
from data_directory_path import data_directory
import os
os.chdir(data_directory)

save = True

#%%
data = pd.read_csv('./data/data_all.csv', sep=',')
data['Date'] = pd.to_datetime(data['Date'], format='%Y%m%d')

cols = ['PRI_circle', 'REP_circle']
titles = ['(a)', '(b)']
y_labs = [  'PRI', 'REP (nm)']

fig, axs = plt.subplots(nrows=1, ncols=2, figsize=(10, 3))
plt.subplots_adjust(hspace=0.4, wspace= 0.2)

# set font sizes
SMALL_SIZE = 12
MEDIUM_SIZE = 14
BIGGER_SIZE = 16
plt.rc('font', size=MEDIUM_SIZE) 
plt.rc('axes', titlesize=MEDIUM_SIZE)  
plt.rc('axes', labelsize=MEDIUM_SIZE) 
plt.rc('xtick', labelsize=SMALL_SIZE)   
plt.rc('ytick', labelsize=SMALL_SIZE)    
plt.rc('legend', fontsize=SMALL_SIZE)    

for y_lab, title, col, ax in zip(y_labs, titles, cols, axs.ravel()) :
    sns.lineplot(data=data, ax=ax, 
             x='Date', y=col, palette= c_palette,
             hue='Pot_ID', hue_order=['6C', '25C', '28C', '30C', '9D', '10D', '54D', '55D'],
             errorbar=('ci', 95))
    
    ax.text(0.1, .95, title, ha='left', va='top', transform=ax.transAxes,  
            fontdict ={'size':14, 'weight': 'bold'})
    ax.set_xlabel('')
    ax.set_ylabel(y_lab)
    if col == cols[1]:
        handles, labels = ax.get_legend_handles_labels()
        lgdn = ax.legend(handles=handles, labels=labels, 
                         title='Plant ID', 
                         loc='center right', 
                         bbox_to_anchor=(1.4, 0.5),
                         fancybox=True)
    else:
         lgdn = ax.legend()
         lgdn.remove()

    ax.yaxis.set_major_locator(ticker.MaxNLocator(3))
    ax.set_xticks(ticks=[pd.to_datetime('2022-08-15'),
                        pd.to_datetime('2022-08-31')])
    ax.xaxis.set_major_formatter(mdates.DateFormatter('%b %d'))
    ax.tick_params(axis='x', labelrotation=0)

    y_min, y_max = data[col].min(), data[col].max()
    diff = y_max - y_min
    ax.scatter(pd.to_datetime('2022-08-14 22:00'), y_min + diff*0.05,
               c=c_palette[5], edgecolor=c_palette[5], linewidth=0.2,
                marker=r'$\downarrow$',s=400, label='Irrigation\nresumed', zorder=2)
    ax.scatter(pd.to_datetime('2022-08-30 22:00'), y_min + diff*0.05, 
               c=c_palette[1], edgecolor=c_palette[1], linewidth=0.2,
                marker=r'$\downarrow$',s=400, label='Irrigation\nresumed', zorder=2)


plt.tight_layout()

if save == True:
    output_fn = './graphs/Figure_A5'
    plt.savefig(output_fn + '.png',  bbox_inches='tight', dpi=600)
    plt.savefig(output_fn + '.pdf',  bbox_inches='tight', dpi=600)

plt.show()
