#%%
"""
Plot RGB image with circular masks and ID labels (Appendix Fig. A5)
"""

import hsi_functions as hsi
import spectral as spy
import numpy as np
import matplotlib.pyplot as plt
import pandas as pd
import glob
from data_directory_path import data_directory
import os
os.chdir(data_directory)

# save plot?
save = True

files = glob.glob('./data/HSI/output/refl_HSI_data/*.dat')
files = [fn.replace('.dat', '') for fn in files]


def stack_rgb(im,bands):
    """
    Function to find band RGB, and stack them into an 0-255 value integer array
    """
    
    red = im[bands[0]]
    red[red<0] = 0
    red *= (255.0/np.nanmax(red))
    green = im[bands[1]]
    green[green<0] = 0
    green *= (255.0/np.nanmax(green))
    blue = im[bands[2]]
    blue[blue<0] = 0
    blue *= (255.0/np.nanmax(blue))
    
    stackedRGB = np.stack((red,green,blue),axis=2)
    integer_array = np.round(stackedRGB).astype(int) 
    
    return integer_array 


#%%
fig, axs = plt.subplots(4, 4, figsize=(15,15))
plt.subplots_adjust(hspace = 0.15, wspace= 0)

for file, ax in zip(files, axs.ravel()): 
    date = file[32:40]
    im = hsi.read_img(file)
    wav, fwhm = hsi.get_wav(file)
    rgb_im = np.transpose(im, (1,2,0))

    iRed = hsi.find_nearest_idx(wav, 630)
    iGreen = hsi.find_nearest_idx(wav, 530)
    iBlue = 3

    rgb_im = stack_rgb(im, [iRed, iGreen, iBlue])
    rgb_im = (rgb_im-0)/(50-0)

    ax.imshow(rgb_im)
    ax.tick_params(bottom = False, left= False)
    ax.set(title=pd.to_datetime(date, format='%Y%m%d').strftime('%b %d'), xticklabels=[], yticklabels=[])

axs[3,2].axis('off')
axs[3,3].axis('off')

plt.tight_layout()

if save == True:
    output_fn = './graphs/Figure_A6'
    plt.savefig(output_fn + '.png',  bbox_inches='tight', dpi=600)
    plt.savefig(output_fn + '.pdf',  bbox_inches='tight', dpi=600)

plt.show()

