#%%
"""
Plot Pearson's r correlation matrix (Appendix Fig. A7)
"""

import pandas as pd
import numpy as np
import matplotlib.pyplot as plt
import seaborn as sns
from data_directory_path import data_directory
import os
os.chdir(data_directory)

data = pd.read_csv('./data/data_all__nosat.csv', sep=',')

# Save plot? 
save = False

#%%
corr_columns = ['F0', 'Fm.', 'YII_MAX',
                "F's", "F'm",'YII',
                'qLs', 'qLr', 'qLT', 
                'Y_NPQs', 'Y_NPQr', 'Y_NPQ', 
                'NPQs','NPQr', 'NPQ',
                'Y_No','LWP',
                'SM', 'PRI_circle', 'REP_circle', 
                'CONC VIO','CONC ANTERA','CONC ZEAX', 'TOTAL VAZ','A+Z/VAZ',
                'CON NEO', 'CONC LUT','CONC LX',  
                'a-CAROT', 'B-CAROT', 'TOTAL CAROT', 
                'CLORF a+b',  'CAROT TOT/CLORF (a+b)',
                'E_correct', 'A_correct']

data = data[corr_columns]

new_names = ["$\mathit{F_{0}}$", 
             "$\mathit{F_{M}}$",
             'Φ$\mathit{PSII_{MAX}}$',
             "$\mathit{F'_{S}}$", 
             "$\mathit{F'_{M}}$",
             'Φ$\mathit{PSII}$', 
             '$\mathit{qLs}$',
             '$\mathit{qLr}$',
             '$\mathit{qLT}$', 
             'Φ$\mathit{NPQ_{S}}$', 
             'Φ$\mathit{NPQ_{R}}$',
             'Φ$\mathit{NPQ}$', 
             'K$\mathit{_{NPQ}}$', 
             'K$\mathit{_{NPQr}}$',
             'K$\mathit{_{NPQ}}$', 
             'Φ$\mathit{N_{O}}$', 
             'Ψ$\mathregular{_{W}}$',
             'SM-%',
             'PRI',
             'REP',
             'Vio', 
             'Ant',
             'Zea',
             'VAZ',
             'A+Z/VAZ',
             'Neo',
             'Lut',
             'Lx',
             'a-carot.',
             'B-carot.',
             'Total carot.', 
             'Chl',
             'Total carot. /\nChl',
             '$\mathit{E}$',
             '$\mathit{A}$']

data.columns = new_names

method = 'pearson'
corr = data.corr(method=method)
#%%
mask = np.triu(np.ones_like(corr, dtype=bool))

# Set up the matplotlib figure
f, ax = plt.subplots(figsize=(11, 9))

# colormap
cmap = 'Spectral' 

# Draw the heatmap with the mask and correct aspect ratio
sns.heatmap(corr, cmap=cmap, mask=mask, center=0,
            square=True, linewidths=.5, cbar_kws={"shrink": .5}) # 

labels = corr.columns.tolist()
plt.gca().set_xticks(np.arange(len(labels)) + 0.5)
plt.gca().set_yticks(np.arange(len(labels)) + 0.5)

plt.gca().set_xticklabels(labels,rotation=90, fontsize=6)
plt.gca().set_yticklabels(labels,rotation=0, fontsize=6)


if save:
    output_fn = './graphs/Figure_A7__nosat'
    plt.savefig(output_fn + '.png',  bbox_inches='tight', dpi=600)
    plt.savefig(output_fn + '.pdf',  bbox_inches='tight', dpi=600)

plt.show()
