#%%
"""
Plot manual masks from 31 Aug (Fig. 1e and Appendix Fig. A8)
"""

import tifffile
import matplotlib.pyplot as plt
import numpy as np
from PIL.ImageColor import getcolor
from matplotlib.patches import Patch
from matplotlib.lines import Line2D
from data_directory_path import data_directory
import os
os.chdir(data_directory)

# Save plot? 
save = True

#%%
mask_path =  './data/HSI/output/masks/' + '20220831-mask.tiff'
mask = tifffile.imread(mask_path)

color_map = {0: np.array([255, 255, 255]), 
             601: np.array(getcolor('#1474b2', "RGB")),  
             602: np.array(getcolor('#1474b2', "RGB")),  
             901: np.array(getcolor('#aa3c03', "RGB")),  
             902: np.array(getcolor('#aa3c03', "RGB")), 
             1001:np.array(getcolor('#e1640e', "RGB")),
             1002:np.array(getcolor('#e1640e', "RGB")), 
             2501:np.array(getcolor('#42a6cc', "RGB")),
             2502:np.array(getcolor('#42a6cc', "RGB")),
             2801:np.array(getcolor('#7bccc4', "RGB")), 
             2802:np.array(getcolor('#7bccc4', "RGB")), 
             3001:np.array(getcolor('#b4e2ba', "RGB")), 
             3002:np.array(getcolor('#b4e2ba', "RGB")),
             5401:np.array(getcolor('#fe9929', "RGB")), 
             5402:np.array(getcolor('#fe9929', "RGB")), 
             5501:np.array(getcolor('#fece65', "RGB")), 
             5502:np.array(getcolor('#fece65', "RGB"))}

data = mask
data_3d = np.ndarray(shape=(data.shape[0], data.shape[1], 3), dtype=int)
for i in range(0, data.shape[0]):
    for j in range(0, data.shape[1]):
        data_3d[i][j] = color_map[data[i][j]]

levels = np.unique(mask)

fig, ax = plt.subplots(1,1)
plt.contourf(mask, levels, hatches=['','//','','//','','//','','//','','//','','//','','//','','//',''], alpha=0)
plt.axis('off')

custom_fills = [Patch(facecolor='gray', edgecolor='black',),
                Patch(facecolor='gray', edgecolor='black', hatch='//')]

custom_fills_shoots = [Line2D([0], [0], color= 'w', markersize=10, marker='o',markerfacecolor='#1474b2'),
                       Line2D([0], [0], color= 'w', markersize=10, marker='o',markerfacecolor='#42a6cc'),
                       Line2D([0], [0], color= 'w', markersize=10, marker='o',markerfacecolor='#7bccc4'),
                       Line2D([0], [0], color= 'w', markersize=10, marker='o',markerfacecolor='#b4e2ba'),
                       Line2D([0], [0], color= 'w', markersize=10, marker='o',markerfacecolor='#aa3c03'),
                       Line2D([0], [0], color= 'w', markersize=10, marker='o',markerfacecolor='#e1640e'),
                       Line2D([0], [0], color= 'w', markersize=10, marker='o',markerfacecolor='#fe9929'),
                       Line2D([0], [0], color= 'w', markersize=10, marker='o',markerfacecolor='#fece65')]



fig.legend(custom_fills, ['Primary shoot', 'Lateral shoot'], 
           bbox_to_anchor=(1.07,0.75),
           ncol = 1,
           frameon=False)


fig.legend(custom_fills_shoots, 
           ['6C', '25C', '28C', '30C', '9D', '10D', '54D', '55D'], 
           bbox_to_anchor=(0.965,0.61), 
           ncol = 1,
           frameon=False,
           title='Plant ID')

ax.imshow(data_3d)

if save == True:
    output_fn = './graphs/Figure_A8'
    fig.savefig(output_fn + '.png', format='png', dpi=600,bbox_inches='tight')
    fig.savefig(output_fn + '.pdf', format='pdf', dpi=600,bbox_inches='tight')

plt.show()