#%%
"""
- Determine references FmR and F0R using linear regression and YPSII_MAX reference value 0.85
- Determine references FmR' linear regression and YPSII_MAX reference value 0.85
- (remove outliers)
- Calculate indices NPQs, PQs, PQs_max, qLs, Y_IImax, Y_NPQs, Y_No, Y_NPQr
"""

import matplotlib.pyplot as plt
import pandas as pd
import numpy as np
from sklearn.linear_model import LinearRegression
from matplotlib.lines import Line2D
from data_directory_path import data_directory
import os
os.chdir(data_directory)

# remove outliers based on Fm?
rm_outliers = False
# Save output?
save_output = False
# save plots?
save_plots = False

# read raw data from PAM
data = pd.read_csv('./data/PAM/PAM_output/PAM_raw.csv', sep=',')
#data['Date'] = pd.to_datetime(data['Date'], format='%Y%m%d')

#%%
# read data f5rom GFS
gfs_data = pd.read_csv('./data/GFS/GFS_output/GFS_per_pot.csv', sep=',')
#gfs_data['Date'] = pd.to_datetime(gfs_data['Date'], format='%Y%m%d')
gfs_data = gfs_data[['Date', 'Pot', 'Treatment',"F'", "F'm", 'Y_P']]

# merge dataframes by date, pot, and treatment
pam_data = pd.merge(data, gfs_data, on=['Date', 'Pot', 'Treatment'], how='outer')

if rm_outliers:
    # remove outliers based on Fm
    Q1 = np.percentile(data['Fm.'], 25)
    Q3 = np.percentile(data['Fm.'], 75)
    IQR = Q3 - Q1
    min_val = Q1 - 1.5*IQR
    max_val = Q3 + 1.5*IQR
    removed_data = data[(data['Fm.'] < min_val) | (data['Fm.'] > max_val)]  # five repeats
    removed_data.to_csv('../data/PAM/output/PAM_outliers.csv', sep=',', index=False)
    data = data[(data['Fm.'] >= min_val) & (data['Fm.'] <= max_val)] 
    print('Outliers removed and saved in ../data/PAM/output/PAM_outliers.csv')

# make new columns for F0R, FmR FmR'
pam_data['F0R'] = 0 
pam_data['FmR'] = 0
pam_data["F'mR"] = 0
pam_data["F'R"] = 0

fvfm_max = 0.85 


## get FmR and F0R and plot linear regression 
# set references by pot
samples = data['Pot'].unique()
fig, axs = plt.subplots(2,4, figsize=(11,5))

for samplen, ax in zip(samples, axs.ravel()): 
    data_temp = pam_data[(pam_data['Pot'] == samplen)]
    data_temp = data_temp[(data_temp['Date'] == 20220815) | (data_temp['Date'] == 20220818) | (data_temp['Date'] == 20220819) | (data_temp['Date'] == 20220809)]

    x = np.array(data_temp['Y.II.']).reshape((-1, 1))
    y_Fm = np.array(data_temp['Fm.']).reshape((-1, 1))
    y_F0 = np.array(data_temp['F0']).reshape((-1, 1))
    model_Fm = LinearRegression().fit(x, y_Fm)
    y_Fm_pred = model_Fm.predict(np.append(x, fvfm_max).reshape((-1, 1)))
    FmR = model_Fm.predict(np.array([fvfm_max]).reshape((-1, 1)))

    FmR = float(FmR[0,0])
    pam_data.loc[pam_data.Pot == samplen, 'FmR'] = FmR

    F0R = (1-fvfm_max)*FmR
    pam_data.loc[pam_data.Pot == samplen, 'F0R'] = F0R

    ax.plot(np.append(x, fvfm_max), y_Fm_pred, color='black')
    ax.scatter(x, y_Fm, color='#e1640e')
    ax.scatter(x, y_F0, color='#42a6cc')
    ax.scatter(fvfm_max, F0R, color='#42a6cc', marker='x')
    ax.scatter(fvfm_max, FmR, color='#e1640e', marker='x')
    ax.text(.8, 0.55, s = 'R$\mathregular{^{2}}$ = ' + str(round(model_Fm.score(x, y_Fm), 2)), horizontalalignment='center',
     verticalalignment='center', transform=ax.transAxes)
    ax.text(.8, 0.4, s = 'F$\mathregular{_{MR}}$ = ' +  str(round(FmR,2)), horizontalalignment='center',
     verticalalignment='center', transform=ax.transAxes)
    ax.text(.8, 0.25, s = 'F$\mathregular{_{0R}}$ = ' +  str(round(F0R,2)), horizontalalignment='center',
     verticalalignment='center', transform=ax.transAxes)
    ax.set_title('Sample ' + str(samplen))
    ax.set(xlabel='F$\mathregular{_{V}}$' + '/' + 'F$\mathregular{_{M}}$', ylabel='')

legend_elements =  [Line2D([0], [0], marker='o', color='w', label='F$\mathregular{_{M}}$', markerfacecolor='#e1640e', markersize=9),
            Line2D([0], [0], marker='o', color='w', label='F$\mathregular{_{0}}$', markerfacecolor='#42a6cc', markersize=9),
            Line2D([0], [0], marker='x', color='w',  label='F$\mathregular{_{MR}}$, F$\mathregular{_{0R}}$', markeredgecolor='black', markersize=6)]
axs[0,3].legend(handles = legend_elements, loc='lower left')
plt.tight_layout()

if save_plots ==  True:
    plt.savefig('../graphs/PAM/FmR_linreg-2.png', bbox_inches='tight')

plt.show()

samples = data['Pot'].unique()
fig, ax = plt.subplots(1,1, figsize=(4,3))

data_temp = pam_data.dropna()

x = np.array(data_temp['Y_P']).reshape((-1, 1))
y_Fm = np.array(data_temp["F'm"]).reshape((-1, 1))
y_F = np.array(data_temp["F'"]).reshape((-1, 1))
model_Fm = LinearRegression().fit(x, y_Fm)
y_Fm_pred = model_Fm.predict(np.append(x, fvfm_max).reshape((-1, 1)))
FmR = model_Fm.predict(np.array([fvfm_max]).reshape((-1, 1)))

FmR = float(FmR[0,0])
pam_data.loc[:,"F'mR"] = FmR

FR = (1-fvfm_max)*FmR
pam_data.loc[:,"F'R"] = FR

ax.plot(x, y_Fm_pred[0:-1], color='black')
ax.scatter(x, y_Fm, color='#e1640e')
ax.scatter(x, y_F, color='#42a6cc')
ax.scatter(fvfm_max, FR, color='#42a6cc', marker='x')
ax.scatter(fvfm_max, FmR, color='#e1640e', marker='x')
ax.text(.8, 0.55, s = 'R$\mathregular{^{2}}$ = ' + str(round(model_Fm.score(x, y_Fm), 2)), horizontalalignment='center',
    verticalalignment='center', transform=ax.transAxes)
ax.text(.8, 0.4, s = 'F$\mathregular{_{MR}}$ = ' +  str(round(FmR,2)), horizontalalignment='center',
    verticalalignment='center', transform=ax.transAxes)
ax.text(.8, 0.25, s = 'F$\mathregular{_{0R}}$ = ' +  str(round(FR,2)), horizontalalignment='center',
    verticalalignment='center', transform=ax.transAxes)
#ax.set_title('Sample ' + str(samplen))
ax.set(xlabel="$\mathregular{Y_{P}}$", ylabel='')

legend_elements =  [Line2D([0], [0], marker='o', color='w', label="F$\mathregular{_{M}}$'", markerfacecolor='#e1640e', markersize=9),
            Line2D([0], [0], marker='o', color='w', label="F'", markerfacecolor='#42a6cc', markersize=9),
            Line2D([0], [0], marker='x', color='w',  label="F'$\mathregular{_{MR}}$, F'$\mathregular{_{R}}$", markeredgecolor='black', markersize=6)]
ax.legend(handles = legend_elements, loc='upper left')
plt.tight_layout()

if save_plots == True:
    plt.savefig("../graphs/PAM/FmR'-F'_linreg.png", bbox_inches='tight')

plt.show()

## Calculate indices
pam_data = pam_data.dropna(subset=["Date"])
pam_data['YII_MAX'] = 1 - (pam_data['F0']/pam_data['Fm.']) 
pam_data['YII'] = 1 - (pam_data["F'"]/pam_data["F'm"]) 
pam_data['YII/YII_MAX'] =  pam_data['Y.II.']/pam_data['Y_P']
pam_data['NPQ'] = (pam_data["F'mR"]/pam_data["F'm"]) - 1
pam_data['NPQs'] = (pam_data['FmR']/pam_data['Fm.']) - 1 
pam_data['NPQr'] = (pam_data["F'mR"]/pam_data["F'm"]) - (pam_data['FmR']/pam_data["Fm."])
#pam_data['PQs'] = (pam_data['FmR']/pam_data['F0']) - (pam_data['FmR']/pam_data['Fm.'])
pam_data['PQ'] = (pam_data["F'mR"]/pam_data["F'"]) - (pam_data["F'mR"]/pam_data["F'm"] )
pam_data['PQs_max'] = (pam_data['FmR']/pam_data['F0R']) - 1
pam_data['qLT'] =  ((1/pam_data["F'"]) - (1/pam_data["F'm"])) / ((1/pam_data["F'R"]) - (1/pam_data["F'mR"])) # open AND functional reaction centers 
pam_data['qLs'] = ((1/pam_data['F0']) - (1/pam_data['Fm.'])) / ((1/pam_data['F0R']) - (1/pam_data['FmR'])) 
pam_data['qLr'] = ((1/pam_data["F'"]) - (1/pam_data["F'm"])) / ((1/pam_data['F0']) - (1/pam_data['Fm.'])) # current open reaction centres from functional 
pam_data['Y_NPQ'] = (pam_data["F'"]/pam_data["F'm"]) - (pam_data["F'"]/pam_data["F'mR"])
pam_data['Y_NPQs'] = (pam_data['F0']/pam_data['Fm.']) - (pam_data['F0']/pam_data['FmR'])
pam_data['Y_NPQr'] = (pam_data["F'"]/pam_data["F'm"]) - (pam_data["F0"]/pam_data["Fm."])
pam_data['Y_No'] = pam_data['F0']/pam_data['FmR']

pam_data = pam_data.loc[:, ~pam_data.columns.isin(['t', 'Time', 'No.', 'ML', 'Temp.', 'PAR', 'ETR'])]

if save_output == True:
    pam_data.to_csv('./data/PAM/PAM_output/PAM_linreg_new.csv', sep=',', index=False)

