"""
Calculate average pri and rep from manually masked primary (PRI1 & REP1) and seconday (PRI2 & REP2) shoot areas and circle masks 
"""
#%%
import numpy as np
import pandas as pd
import tifffile 
import hsi_shoot_locs as shoots
import matplotlib.pyplot as plt

import os
from data_directory_path import data_directory
os.chdir(data_directory)

dir0 = './data/HSI/HSI_output/'
outputdir = './data/HSI/HSI_output/'

# save averages as csv files?
save = True

#%%
### PRI and REP from manual masks

pri_files = ['20220809-pri_R564_im.tiff', '20220831-pri_R564_im.tiff', '20220908-pri_R564_im.tiff']
rep_files = ['20220809-rep_im.tiff', '20220831-rep_im.tiff', '20220908-rep_im.tiff']
ndvi_files = ['20220809-ndvi_im.tiff', '20220831-ndvi_im.tiff', '20220908-ndvi_im.tiff']
mask_files = ['20220809-mask.tiff', '20220831-mask.tiff', '20220908-mask.tiff']

pot_ids = ['54', '25', '10', '28', '9', '6', '55', '30']

pri_dict = {}

for i in range(len(pri_files)):

    dt = pri_files[i][0:8]
    pri_dir =  dir0 + '/PRI-tiffs/' + pri_files[i]
    pri = tifffile.imread(pri_dir)
    mask_dir = dir0 + '/masks/' + mask_files[i]
    mask = tifffile.imread(mask_dir)

    pri_dict[dt] = {}

    for pot in pot_ids:
        mask_all = np.ma.masked_outside(mask, float(pot + '01'), float(pot + '02'))
        mask_all = np.ma.getmask(mask_all)
        pri_all = np.ma.masked_array(pri, mask_all)
        pri_dict[dt][pot] = np.nanmean(pri_all)

        pri_1 = np.ma.masked_where(mask != float(pot + '01'), pri)
        pri_dict[dt][pot+ '01'] = np.nanmean(pri_1)

        pri_2 = np.ma.masked_where(mask != float(pot + '02'), pri)
        pri_dict[dt][pot+ '02'] = np.nanmean(pri_2)

pri_df = pd.DataFrame.from_dict(pri_dict)
pri_df = pri_df.transpose()

output_fn = outputdir + 'pri_by-shoot_R564__nosat.csv'

if save:
    pd.DataFrame.to_csv(pri_df, output_fn)

rep_dict = {}

for i in range(len(rep_files)):
    dt = rep_files[i][0:8]
    rep_dir = dir0 + '/REP-tiffs/' + rep_files[i]
    rep = tifffile.imread(rep_dir)
    mask_dir = dir0 + '/masks/' + mask_files[i]
    mask = tifffile.imread(mask_dir)

    rep_dict[dt] = {}

    for pot in pot_ids:
        mask_all = np.ma.masked_outside(mask, float(pot + '01'), float(pot + '02'))
        mask_all = np.ma.getmask(mask_all)
        rep_all = np.ma.masked_array(rep, mask_all)
        rep_dict[dt][pot] = np.nanmean(rep_all)

        rep_1 = np.ma.masked_where(mask != float(pot + '01'), rep)
        rep_dict[dt][pot+ '01'] = np.nanmean(rep_1)

        rep_2 = np.ma.masked_where(mask != float(pot + '02'), rep)
        rep_dict[dt][pot+ '02'] = np.nanmean(rep_2)

rep_df = pd.DataFrame.from_dict(rep_dict)
rep_df = rep_df.transpose()

output_fn = outputdir + 'rep_by-shoot__nosat.csv'

if save:
    pd.DataFrame.to_csv(rep_df, output_fn)

#%%
### PRI and REP circle mask averages 
def circle_mask_av(index_im, radius, key, i, show_plot= True):
    center = shoots.sloc_dict[key][i]
    h = 1024
    w = 1024
    Y, X = np.ogrid[:h, :w]
    dist_from_center = np.sqrt((X - center[0])**2 + (Y-center[1])**2)

    mask = dist_from_center >= radius
    im_masked = np.ma.masked_array(index_im, mask = mask)
    masked_av = np.nanmean(im_masked)
    
    if show_plot:
        plt.imshow(im_masked)
        plt.show()

    return masked_av

pri_files = [f for f in os.listdir(dir0 + '/PRI-tiffs/') if f.endswith('pri_R564_im.tiff')]
rep_files = [f for f in os.listdir(dir0 + '/REP-tiffs/') if f.endswith('rep_im.tiff')]

pri_circle_dict = {}
rep_circle_dict = {}

for pri_file, rep_file in zip(pri_files, rep_files):
    dt = pri_file[0:8]
    pri_dir =  dir0 + '/PRI-tiffs/' + pri_file
    pri = tifffile.imread(pri_dir)
    rep_dir = dir0 + '/REP-tiffs/' + rep_file
    rep = tifffile.imread(rep_dir)

    pri_circle_dict[dt] = {'54':'', '25':'', '10':'', '28':'', '9':'', '6':'', '55':'', '30':''}
    rep_circle_dict[dt] = {'54':'', '25':'', '10':'', '28':'', '9':'', '6':'', '55':'', '30':''}

    for key, i in zip(pri_circle_dict[dt].keys(), range(8)):
        pri_circle_dict[dt][key] = circle_mask_av(pri, 50, dt, i, show_plot=True)
        rep_circle_dict[dt][key] = circle_mask_av(rep, 50, dt, i, show_plot=True)


pri_df = pd.DataFrame.from_dict(pri_circle_dict)
if save:
    pd.DataFrame.to_csv(pri_df, './data/HSI/HSI_output/pri_R564_circle__nosat.csv')

rep_df = pd.DataFrame.from_dict(rep_circle_dict)
if save:
    pd.DataFrame.to_csv(rep_df, './data/HSI/HSI_output/rep_circle__nosat.csv')

# %%
