"""
Open all reflectance cubes, calculate pri, rep, and ndvi, and save them as tiffs 
"""
#%%
import tifffile as tifffile
import hsi_functions as hsi
import os 
from data_directory_path import data_directory

os.chdir(data_directory)

dir0 = './data/HSI/HSI_output/'
im_paths = [f for f in os.listdir(dir0 +  'refl_HSI_data/') if f.endswith('.dat')]
im_paths = [ele.replace('.dat', '') for ele in im_paths]

# save tiffs?
save = True

#%%
for path in im_paths:
    im_path = dir0 + 'refl_HSI_data/' + path
    dt =  path[0:8]

    print('Opening image', dt)
    im = hsi.read_img(im_path)
    wav, fwhm = hsi.get_wav(im_path)

    pri = hsi.calc_pri_564(im, wav)
    rep = hsi.calc_rep(im, wav)
    ndvi = hsi.calc_ndvi(im, wav)

    output_pri=  dir0 + 'PRI-tiffs/' + dt + '-pri_R564_im.tiff'
    output_rep=  dir0 + 'REP-tiffs/' + dt + '-rep_im.tiff'
    output_ndvi= dir0 + 'NDVI-tiffs/' + dt + '-ndvi_im.tiff'

    if save == True:
        tifffile.imsave(output_pri, pri)
        tifffile.imsave(output_ndvi, ndvi)
        tifffile.imsave(output_rep, rep)

    print(' ---- Done with ', dt, ' ----')


print('Done.')



