"""
Process summer 2022 HSI to reflectance by date
"""
#%%
import hsi_functions as hsi
import matplotlib.pyplot as plt
import numpy as np
import pandas as pd
from random import randint
import os
from data_directory_path import data_directory

os.chdir(data_directory)

dir0  = './data/HSI/HSI_raw/'
outpath = './data/HSI/HSI_output/refl_HSI_data/rmsat/'

save_cube = True

## get notes
HSI_all_notes = pd.read_csv(dir0 + '/HSI_notes.csv', delimiter=',')

## get unique dates
HSI_dates = HSI_all_notes['date'].unique()
## or set custom date
HSI_dates = [20220823]


#%%
## Loop through days by IT
for dt in HSI_dates:

    print('--- Processing', dt, ' ---')

    HSI_notes__dt = HSI_all_notes[(HSI_all_notes['date'] == dt)]
    HSI_notes__dt = HSI_notes__dt.reset_index(drop=True)
    HSI_notes = HSI_notes__dt.reset_index(drop=True)

    for i in range(len(HSI_notes['path'])):
            HSI_notes['path'][i] = dir0 + HSI_notes['path'][i]

    ITs = HSI_notes['IT'].unique() 

    print('Selected ITs on', dt, 'are', ITs) 
    WR_it = ITs.min()

    print('Getting WR from IT', WR_it)
    WR_img = hsi.sample_ave(WR_it, HSI_notes)
    output_nm = outpath + str(dt) +'_WR_report__rmsat'
    WR = hsi.wr_spec_w_report(WR_img, output_nm, dt) 
    WR_DC = hsi.get_DC(WR_it, HSI_notes)
    
    refl_arrays = []


    for IT in ITs:
        print('Getting DC from IT', IT)
        DC = hsi.get_DC(IT, HSI_notes)
        print('Averaging sample cubes from IT', IT)
        img_av = hsi.sample_ave(IT, HSI_notes, rm_sat=True)
        print('Calculating sample reflectance IT', IT)
        img_refl = np.copy(img_av)
        for i in range(img_refl.shape[0]):
            img_refl[i] = (img_refl[i]-DC[i])/(WR[i]-WR_DC[i]) 

        refl_arrays.append(img_refl)         

    print('Averaging all ITs from', dt)
    header_fn = pd.Series.tolist(HSI_notes__dt['path'])
    header_fn = './data/HSI/HSI_raw/' + header_fn[0]
    output_nm = outpath + '/' + str(dt) + '_refl__rmsat'
    img_refl_all_ITs = np.nanmean(refl_arrays, axis = 0)

    if save_cube:
        hsi.save_cube(img_refl_all_ITs, header_fn, output_nm)

    ## plot to check
    bandn = 5
    plt.imshow(img_refl_all_ITs[bandn])
    plt.title('Reflectance layer ' + str(bandn) + ', ' + str(dt))
    plt.colorbar()
    plt.show()


    px = [(randint(1, 1024), randint(1, 1024)) for i in range(50)]
    py = [(randint(1, 1024), randint(1, 1024)) for i in range(50)]
    for x, y in zip(px, py):
        plt.plot(img_refl_all_ITs[:, x, y], color='gray', alpha = 0.3)    
    plt.title('Random pixel reflectance, ' + str(dt))
    plt.show()

    print('--- Done with', dt, '---')


# %%
